@@ -50,6 +50,8 @@ export const PERMISSION_NOUNS = [
   'PatientFamilyHistory',
   'PatientIssue',
   'PatientLetterTemplate',
+  'PatientPortalRegistration',
+  'PatientPortalForm',
   'PatientProgramRegistration',
   'PatientProgramRegistrationCondition',
   'PatientSecondaryId',
@@ -84,6 +86,7 @@ export const PERMISSION_NOUNS = [
   'User',
   'Vitals',
   'SensitiveMedication',
+  'LocationSchedule',
 ];
 
 export const NOUNS_WITH_OBJECT_ID = [
