@@ -3,3 +3,6 @@ export * from './getDependentAssociations';
 export * from './onCreateEncounterMarkPatientForSync';
 export * from './sortInDependencyOrder';
 export * from './fhir';
+export * from './audit';
+export * from './convertDatabaseError';
+export * from './tablesWithTrigger';
